.. _Nipype: http://nipype.readthedocs.io/en/latest/
.. _BIDS: http://bids.neuroimaging.io
.. _Installation: installation.html
.. _workflows: workflows.html
.. _FSL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/
.. _ANTs: https://stnava.github.io/ANTs/
.. _AFNI: https://afni.nimh.nih.gov/
.. _FreeSurfer: https://surfer.nmr.mgh.harvard.edu/
.. _DIPY: https://dipy.org/
